package fs

import (
	"fmt"
	"os/exec"
	"strings"
)

// ErrMount is an error from an external command
type ErrMount struct {
	output  []byte
	command []string
}

func (e ErrMount) Error() string {
	return fmt.Sprintf("error while executing external command %s: %s", strings.Join(e.command, " "), e.output)
}

func execute(cmd []string) error {
	if out, err := exec.Command(cmd[0], cmd[1:]...).CombinedOutput(); err != nil {
		return &ErrMount{command: cmd, output: out}
	}

	return nil
}

// BindMount mounts src to dst
func BindMount(src, dst string) error {
	return execute([]string{"mount", "--bind", src, dst})
}

// Mount mounts src to dst
func Mount(src, dst string) error {
	return execute([]string{"mount", src, dst})
}

// Unmount unmounts path
func Unmount(path string) error {
	return execute([]string{"umount", path})
}
